Error

Enum Error 

pub enum Error<Ctx>
where Ctx: Context,
{ NoProposer(Ctx::Height, Round), ProposerNotFound(Ctx::Address), ValidatorNotFound(Ctx::Address), InvalidProposalHeight { proposal_height: Ctx::Height, consensus_height: Ctx::Height, }, InvalidVoteHeight { vote_height: Ctx::Height, consensus_height: Ctx::Height, }, InvalidCertificateHeight { certificate_height: Ctx::Height, consensus_height: Ctx::Height, }, CertificateNotFound { round: Round, value_id: <Ctx::Value as Value>::Id, }, }
The type of errors that can be yielded by the Driver.

Variants



NoProposer(Ctx::Height, Round)

No proposer was set for this round



ProposerNotFound(Ctx::Address)

Proposer not found



ValidatorNotFound(Ctx::Address)

Validator not found in validator set



InvalidProposalHeight

Received a proposal for another height

Fields

proposal_height: Ctx::Height

Proposal height

consensus_height: Ctx::Height

Consensus height



InvalidVoteHeight

Received a vote for another height

Fields

vote_height: Ctx::Height

Vote height

consensus_height: Ctx::Height

Consensus height



InvalidCertificateHeight

Received a certificate for another height

Fields

certificate_height: Ctx::Height

Certificate height

consensus_height: Ctx::Height

Consensus height



CertificateNotFound

Commit certificate not found for the given round and value

Fields

round: Round

The round

value_id: <Ctx::Value as Value>::Id

The value ID